::: laktory.models.resources.databricks.SecretScope

---

::: laktory.models.resources.databricks.secretscope.SecretScopePermission

---

::: laktory.models.resources.databricks.secretscope.SecretScopeKeyvaultMetadata

---